Changelog
---------

0.1.3 (2016-11-25)
~~~~~~~~~~~~~~~~~~~

- Fix datetime picker not showing the hour/minutes in the placeholder.
  [href]

- Point the default map view to the Seantis office.
  [href]

- Improve multi-line checkbox/radio-button handling.
  [href]

0.1.2 (2016-11-18)
~~~~~~~~~~~~~~~~~~~

- Adds a jquery plugin to easily toggle blocks by button.
  [href]

- Fixes userprofile data being lost on erronous input.
  [href]

- Fixes datetime/date picker weeks not starting on the region-specific day.
  [href]

- Adds a to_timezone helper function to the default layout.
  [href]

0.1.1 (2016-11-02)
~~~~~~~~~~~~~~~~~~~

- Generate links in top-navigation just like it is done in other palces.
  [href]

- Automatically skip the login view if the target url is accessable.
  [href]

0.1.0 (2016-10-26)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to stick certain news items to the homepage.
  [href]

- Make sure that all time input fields support input parsing.
  [href]

- Accept a wider range of values in the time input fields.
  [href]

- Fix search url being wrong after multiple searches.
  [href]

- Upgrade to latest React release.
  [href]

- Adds the ability to easily switch between resources.
  [href]

- Use auto-height for fullcalendar, mainly to improve mobile usage.
  [href]

- Upgrade to Fullcalendar 3.0.1.
  [href]

- Fixes telephone links not working in person detail view.
  [href]

- Fixes input placeholder having the wrong color in IE11.
  [href]

- Supports excel/csv/json in the events export.
  [href]

- Adds organizer to events export.
  [href]

- Dates in excel exports are now formatted in a localized manner.
  [href]

0.0.14 (2016-10-19)
~~~~~~~~~~~~~~~~~~~

- Adds a separate date_range function for dates instead of datetimes.
  [href]

0.0.13 (2016-10-11)
~~~~~~~~~~~~~~~~~~~

- Hardens all return-to links.
  [href]

- Includes the userprofile in the usermanagement view.
  [href]

- Fixes 'News' title showing up twice on the newsletter view.
  [href]

0.0.12 (2016-10-04)
~~~~~~~~~~~~~~~~~~~

- Adds compatibility with Morepath 0.16.
  [href]

- Adds the ability to easily format a date range.
  [href]

- Adds input-type:datetime support to the datetimepicker.
  [href]

0.0.11 (2016-09-29)
~~~~~~~~~~~~~~~~~~~

- Ensure that all image upload views enforce the same checks.
  [href]

- Order tags by alphabet in events view.
  [href]

0.0.10 (2016-09-22)
~~~~~~~~~~~~~~~~~~~

- Upgrade to latest onegov.core release.
  [href]

0.0.9 (2016-09-22)
~~~~~~~~~~~~~~~~~~~

- Fixes being unable to edit builtin forms.
  [href]

- Adds a ConfirmLink element which works like a DeleteLink but for POST.
  [href]

- Fixes title being shown twice on the news site.
  [href]

0.0.8 (2016-09-12)
~~~~~~~~~~~~~~~~~~~

- Fixes morepath directives not working in all cases.
  [href]

0.0.7 (2016-09-12)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to define a custom homepage through widgets.
  [href]

- Use a uuid converter for all uuid-ids to turn bad requests into 404s.
  [href]

- Adds the ability to override the initial content creation function.
  [href]

- Fixes user editing not working when yubikeys are enabled.
  [href]

0.0.6 (2016-08-31)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to manage users in a usermanagement view.
  [href]

0.0.5 (2016-08-26)
~~~~~~~~~~~~~~~~~~~

- Enables the user profile for simple members.
  [href]

- Adds the ability for new users to register themselves.
  [href]

0.0.4 (2016-08-25)
~~~~~~~~~~~~~~~~~~~

- Fixes upgrade not working in all cases.
  [href]

0.0.3 (2016-08-25)
~~~~~~~~~~~~~~~~~~~

- Possibly fixes release not working for PyPI.
  [href]

0.0.2 (2016-08-24)
~~~~~~~~~~~~~~~~~~~

- Removes dependency to itself.
  [href]

0.0.1 (2016-08-24)
~~~~~~~~~~~~~~~~~~~

- Initial Release
